/*
 * Copyright (c) Openmind.  All rights reserved. http://www.openmindonline.it
 */
package it.openutils.testing.testng.utils;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

import org.testng.Assert;


/**
 * Utility methods for checking dates in unit tests.
 * @author fgiust
 * @version $Id: DateAssert.java 195 2007-02-05 08:27:20Z fcarone $
 */
public final class DateAssert
{

    private static DateFormat df = new SimpleDateFormat("yyyyMMdd");

    private static DateFormat dtf = new SimpleDateFormat("yyyyMMdd HH:mm");

    /**
     * Don't instantiate.
     */
    private DateAssert()
    {
        // unused
    }

    /**
     * Asserts that two dates are equal.
     * @param expectedDateAsString date formatted as "YYYYMMDD"
     * @param date actual date
     * @throws IllegalArgumentException if <code>expectedDateAsString</code> is not a valid date format
     */
    public static void dateEqual(String expectedDateAsString, Calendar date) throws IllegalArgumentException
    {
        Date expected;

        try
        {
            expected = df.parse(expectedDateAsString);
        }
        catch (ParseException e)
        {
            throw new IllegalArgumentException("Unparseable date String: [" + expectedDateAsString + "]");
        }

        if (date == null)
        {
            throw new AssertionError("Date is null");
        }

        Assert.assertEquals(date.getTime(), expected);
    }

    /**
     * Asserts that two dates are equal.
     * @param expectedDateAsString date formatted as "yyyyMMdd HH:mm"
     * @param date actual date
     * @throws IllegalArgumentException if <code>expectedDateAsString</code> is not a valid date format
     */
    public static void dateTimeEqual(String expectedDateAsString, Date date) throws IllegalArgumentException
    {
        Date expected;

        try
        {
            expected = dtf.parse(expectedDateAsString);
        }
        catch (ParseException e)
        {
            throw new IllegalArgumentException("Unparseable date String: [" + expectedDateAsString + "]");
        }

        if (date == null)
        {
            throw new AssertionError("Date is null");
        }

        if (date.getTime() != expected.getTime())
        {
            throw new AssertionError("Expected <" + expected + ">, actual <" + date + ">");
        }
    }

    /**
     * Asserts that two dates are equal.
     * @param expectedDateAsString date formatted as "yyyyMMdd HH:mm"
     * @param date actual date
     * @throws IllegalArgumentException if <code>expectedDateAsString</code> is not a valid date format
     */
    public static void dateTimeEqual(String expectedDateAsString, Calendar date) throws IllegalArgumentException
    {
        dateTimeEqual(expectedDateAsString, date.getTime());
    }

}
